@@ -1,7 +1,9 @@
 use crate::command::trove::CommandTrove;
 use crate::gui::merge::{with_conflict_resolve_prompt, ConflictResolve};
-use crate::gui::prompts::{prompt_input, prompt_input_validate};
+use crate::gui::prompts::{prompt_input, prompt_input_validate, prompt_select_with_options};
 use crate::util::string_find_next;
+use rand::distributions::Alphanumeric;
+use rand::Rng;
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -83,9 +85,7 @@ impl HoardCommand {
         parameter_ending_token: &str,
     ) -> Self {
         let base_prompt = format!(
-            "Command to hoard ( Mark unknown parameters with '{}'. Name the parameter with any string and end it with '{}' )\n",
-            parameter_token,
-            parameter_ending_token
+            "Command to hoard ( Mark unknown parameters with '{parameter_token}'. Name the parameter with any string and end it with '{parameter_ending_token}' )\n"
         );
         let command_string: String = prompt_input(&base_prompt, false, default_value);
         Self {
@@ -124,11 +124,24 @@ impl HoardCommand {
         self.with_tags_raw(&tags)
     }
 
-    pub fn with_namespace_input(self, default_namespace: Option<String>) -> Self {
-        let namespace: String = prompt_input("Namespace of the command", false, default_namespace);
+    pub fn with_namespace_input(self, selection: &[&str]) -> Self {
+        // Add "New namespace" option to selction
+        let mut selection = selection.to_vec();
+        selection.push("New namespace");
+
+        let selected: usize = prompt_select_with_options(
+            "Namespace of the command",
+            &selection,
+        );
+
+        let mut selected_namespace:String = (*selection.get(selected).unwrap()).to_string();
+        if selected_namespace == "New namespace" {
+            selected_namespace = prompt_input("Namespace of the command", false, Some(String::from("default")));
+        }
+
         Self {
             name: self.name,
-            namespace,
+            namespace: selected_namespace,
             tags: self.tags,
             command: self.command,
             description: self.description,
@@ -173,6 +186,22 @@ impl HoardCommand {
         self.with_name_input_prompt(default_value, trove, "Name your command")
     }
 
+    pub fn resolve_name_conflict_random(self) -> Self {
+        let rng = rand::thread_rng();
+        let random_string: String = rng
+            .sample_iter(&Alphanumeric)
+            .take(3)
+            .map(char::from)
+            .collect();
+        Self {
+            name: format!("{}-{random_string}", self.name),
+            namespace: self.namespace,
+            tags: self.tags,
+            command: self.command,
+            description: self.description,
+        }
+    }
+
     pub fn resolve_name_conflict(
         self,
         collision: Self,
@@ -239,7 +268,7 @@ pub trait Parameterized {
     // Count number of parameter pointers
     fn get_parameter_count(&self, token: &str) -> usize;
     fn split(&self, token: &str) -> Vec<String>;
-    // Get parameterized Stringlike subject including parameter token
+    // Get parameterized String like subject including parameter token
     // For example, given subject with parameter token '#1':
     // 'This is a #1 with one parameter token'
     // `get_split_subject("#")` returns
