@@ -8,6 +8,8 @@ use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use url::ParseError;
 
+use dotenv::dotenv;
+
 use crate::cli_commands::Mode;
 use crate::command::hoard_command::HoardCommand;
 use crate::command::trove::CommandTrove;
@@ -22,7 +24,6 @@ use crate::gui::prompts::{
 use crate::sync_models::TokenResponse;
 use crate::util::rem_first_and_last;
 use base64::Engine as _;
-
 #[derive(Default, Debug)]
 pub struct Hoard {
     config: Option<HoardConfig>,
@@ -46,6 +47,7 @@ impl Hoard {
     }
 
     pub async fn start(&mut self) -> (String, bool) {
+        dotenv().ok();
         if !compare_with_latest_version().await.0 {
             println!(
                 "A newer Version ({}) is available at https://github.com/Hyde46/hoard \nPlease update.", compare_with_latest_version().await.1
@@ -137,7 +139,8 @@ impl Hoard {
         command: Option<String>,
         description: Option<String>,
     ) {
-        let default_namespace = self.config.as_ref().unwrap().default_namespace.clone();
+        let trove_namespaces = self.trove.namespaces();
+        //trove_namespaces.push(&default_ns_clone);
         let new_command = HoardCommand::default()
             .with_command_string_input(
                 command,
@@ -156,11 +159,11 @@ impl Hoard {
                     .clone()
                     .unwrap(),
             )
-            .with_namespace_input(Some(default_namespace))
+            .with_namespace_input(&trove_namespaces)
             .with_name_input(name, &self.trove)
             .with_description_input(description)
             .with_tags_input(tags);
-        self.trove.add_command(new_command);
+        self.trove.add_command(new_command, true);
         self.save_trove(None);
     }
 
@@ -293,7 +296,7 @@ impl Hoard {
 
             let mut trove_for_export = CommandTrove::default();
             for command in selected_commands {
-                trove_for_export.add_command(command.clone());
+                trove_for_export.add_command(command.clone(), true);
             }
 
             trove_for_export.save_trove_file(&target_path);
@@ -317,6 +320,8 @@ impl Hoard {
         let command_to_edit = self
             .trove
             .pick_command(self.config.as_ref().unwrap(), command_name);
+
+        let trove_namespaces = self.trove.namespaces();
         match command_to_edit {
             Ok(c) => {
                 println!("{}", c.command);
@@ -341,9 +346,9 @@ impl Hoard {
                     .with_name_input(Some(c.name.clone()), &self.trove)
                     .with_description_input(c.description.clone())
                     .with_tags_input(Some(c.tags_as_string()))
-                    .with_namespace_input(Some(c.namespace));
+                    .with_namespace_input(&trove_namespaces);
                 self.trove.remove_command(command_name).ok();
-                self.trove.add_command(new_command);
+                self.trove.add_command(new_command, true);
                 self.save_trove(None);
             }
             Err(_e) => eprintln!("Could not find command {command_name} to edit"),
@@ -406,7 +411,7 @@ impl Hoard {
             let backup_trove_path_str = format!("{}.bk", trove_path.to_str().unwrap());
             let backup_trove_path = PathBuf::from_str(&backup_trove_path_str).ok().unwrap();
             if backup_trove_path.exists() {
-                if let Confirmation::Yes = prompt_yes_or_no("Found a backup from just before the last time you ran `hoard sync`. Are you sure you want to revert to this state?") {
+                if matches!(prompt_yes_or_no("Found a backup from just before the last time you ran `hoard sync`. Are you sure you want to revert to this state?"), Confirmation::Yes) {
                     let e = fs::remove_file(trove_path);
                     // make clippy happy
                     drop(e);
